//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[allCommonYaku](all-common-yaku.md)

# allCommonYaku

[common]\
val [allCommonYaku](all-common-yaku.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Yaku](../-yaku/index.md)&gt;

所有通常役种
